@@ -298,6 +298,9 @@ class ClientApplication(Frame):
 
     def _prepare_debug_game(self):
         import os
+        import pkg_resources
+        print '__name__', __name__
+        print pkg_resources.resource_filename(__name__, 'scriptcraft/graphic/base.png')
         print os.getcwd()
 
         # load game and add player
